@@ -1,7 +1,7 @@
 package WordList::Phrase::ID::Proverb::KBBI;
 
-our $DATE = '2016-01-08'; # DATE
-our $VERSION = '0.01'; # VERSION
+our $DATE = '2016-01-13'; # DATE
+our $VERSION = '0.02'; # VERSION
 
 use WordList;
 our @ISA = qw(WordList);
@@ -9,6 +9,9 @@ our @ISA = qw(WordList);
 1;
 # ABSTRACT: Proverb phrases from Kamus Besar Bahasa Indonesia
 
+
+
+
 =pod
 
 =encoding UTF-8
@@ -19,7 +22,26 @@ WordList::Phrase::ID::Proverb::KBBI - Proverb phrases from Kamus Besar Bahasa In
 
 =head1 VERSION
 
-This document describes version 0.01 of WordList::Phrase::ID::Proverb::KBBI (from Perl distribution WordList-Phrase-ID-Proverb-KBBI), released on 2016-01-08.
+This document describes version 0.02 of WordList::Phrase::ID::Proverb::KBBI (from Perl distribution WordList-Phrase-ID-Proverb-KBBI), released on 2016-01-13.
+
+=head1 SYNOPSIS
+
+ use WordList::Phrase::ID::Proverb::KBBI;
+
+ my $wl = WordList::Phrase::ID::Proverb::KBBI->new;
+
+ # Pick a (or several) random word(s) from the list
+ my $word = $wl->pick;
+ my @words = $wl->pick(3);
+
+ # Check if a word exists in the list
+ if ($wl->word_exists('foo')) { ... }
+
+ # Call a callback for each word
+ $wl->each_word(sub { my $word = shift; ... });
+
+ # Get all the words
+ my @all_words = $wl->all_words;
 
 =head1 SEE ALSO
 
@@ -54,6 +76,7 @@ the same terms as the Perl 5 programming language system itself.
 
 =cut
 
+
 __DATA__
 ada bangkai ada hering
 ada beras, taruh dalam padi
